[empathy] Adjust for FolksHasPresence -> FolksPresenceOwner



commit 41f5717611c6bb3236ae78a187fd5753bbd9ccf3
Author: Travis Reitter <travis reitter collabora co uk>
Date:   Wed Dec 22 17:22:59 2010 -0800

    Adjust for FolksHasPresence -> FolksPresenceOwner
    
    Fixes bgo#637847.

 libempathy-gtk/empathy-individual-store.c  |   31 +++++++++++++++------------
 libempathy-gtk/empathy-individual-view.c   |    2 +-
 libempathy-gtk/empathy-individual-widget.c |   24 ++++++++++----------
 libempathy-gtk/empathy-persona-store.c     |   16 ++++++++------
 libempathy-gtk/empathy-ui-utils.c          |    4 +-
 libempathy/empathy-contact.c               |   20 +++++++++---------
 6 files changed, 51 insertions(+), 46 deletions(-)
---
diff --git a/libempathy-gtk/empathy-individual-view.c b/libempathy-gtk/empathy-individual-view.c
index e1007ae..06b444e 100644
--- a/libempathy-gtk/empathy-individual-view.c
+++ b/libempathy-gtk/empathy-individual-view.c
@@ -682,7 +682,7 @@ individual_view_drag_motion (GtkWidget *widget,
         }
 
       if (individual != NULL &&
-          folks_has_presence_is_online (FOLKS_HAS_PRESENCE (individual)) &&
+          folks_presence_owner_is_online (FOLKS_PRESENCE_OWNER (individual)) &&
           (caps & EMPATHY_CAPABILITIES_FT))
         {
           gdk_drag_status (context, GDK_ACTION_COPY, time_);
diff --git a/libempathy-gtk/empathy-individual-widget.c b/libempathy-gtk/empathy-individual-widget.c
index 44e7f95..2f7899b 100644
--- a/libempathy-gtk/empathy-individual-widget.c
+++ b/libempathy-gtk/empathy-individual-widget.c
@@ -220,20 +220,20 @@ update_weak_contact (EmpathyIndividualWidget *self)
       personas = folks_individual_get_personas (priv->individual);
       for (l = personas; l != NULL; l = l->next)
         {
-          FolksHasPresence *presence;
+          FolksPresenceOwner *presence;
 
           /* We only want personas which implement FolksPresence */
-          if (!FOLKS_IS_HAS_PRESENCE (l->data))
+          if (!FOLKS_IS_PRESENCE_OWNER (l->data))
             continue;
 
-          presence = FOLKS_HAS_PRESENCE (l->data);
+          presence = FOLKS_PRESENCE_OWNER (l->data);
 
-          if (folks_has_presence_typecmp (
-                  folks_has_presence_get_presence_type (presence),
+          if (folks_presence_owner_typecmp (
+                  folks_presence_owner_get_presence_type (presence),
                   presence_type) > 0
               && TPF_IS_PERSONA (presence))
             {
-              presence_type = folks_has_presence_get_presence_type (presence);
+              presence_type = folks_presence_owner_get_presence_type (presence);
               tp_contact = tpf_persona_get_contact (TPF_PERSONA (l->data));
             }
         }
@@ -1248,13 +1248,13 @@ notify_presence_cb (gpointer folks_object,
   state_image = g_object_get_data (table, "state-image");
 
   /* FIXME: Default messages should be moved into libfolks (bgo#627403) */
-  message = folks_has_presence_get_presence_message (
-      FOLKS_HAS_PRESENCE (folks_object));
+  message = folks_presence_owner_get_presence_message (
+      FOLKS_PRESENCE_OWNER (folks_object));
   if (EMP_STR_EMPTY (message))
     {
       message = empathy_presence_get_default_message (
-          folks_has_presence_get_presence_type (
-              FOLKS_HAS_PRESENCE (folks_object)));
+          folks_presence_owner_get_presence_type (
+              FOLKS_PRESENCE_OWNER (folks_object)));
     }
 
   if (message != NULL)
@@ -1264,8 +1264,8 @@ notify_presence_cb (gpointer folks_object,
 
   gtk_image_set_from_icon_name (GTK_IMAGE (state_image),
       empathy_icon_name_for_presence (
-          folks_has_presence_get_presence_type (
-              FOLKS_HAS_PRESENCE (folks_object))),
+          folks_presence_owner_get_presence_type (
+              FOLKS_PRESENCE_OWNER (folks_object))),
       GTK_ICON_SIZE_BUTTON);
   gtk_widget_show (state_image);
 }
diff --git a/libempathy-gtk/empathy-persona-store.c b/libempathy-gtk/empathy-persona-store.c
index b77e34d..d89ae9e 100644
--- a/libempathy-gtk/empathy-persona-store.c
+++ b/libempathy-gtk/empathy-persona-store.c
@@ -438,7 +438,8 @@ update_persona (EmpathyPersonaStore *self,
       gtk_tree_path_free (path);
 
       /* Get online state now. */
-      now_online = folks_has_presence_is_online (FOLKS_HAS_PRESENCE (persona));
+      now_online = folks_presence_owner_is_online (
+          FOLKS_PRESENCE_OWNER (persona));
 
       /* Get online state before. */
       gtk_tree_model_get (GTK_TREE_MODEL (self), &iter,
@@ -484,11 +485,11 @@ update_persona (EmpathyPersonaStore *self,
           EMPATHY_PERSONA_STORE_COL_DISPLAY_ID,
               folks_persona_get_display_id (persona),
           EMPATHY_PERSONA_STORE_COL_PRESENCE_TYPE,
-              folks_has_presence_get_presence_type (
-                  FOLKS_HAS_PRESENCE (persona)),
+              folks_presence_owner_get_presence_type (
+                  FOLKS_PRESENCE_OWNER (persona)),
           EMPATHY_PERSONA_STORE_COL_STATUS,
-              folks_has_presence_get_presence_message (
-                  FOLKS_HAS_PRESENCE (persona)),
+              folks_presence_owner_get_presence_message (
+                  FOLKS_PRESENCE_OWNER (persona)),
           EMPATHY_PERSONA_STORE_COL_IS_ONLINE, now_online,
           EMPATHY_PERSONA_STORE_COL_CAN_AUDIO_CALL,
               empathy_contact_get_capabilities (contact) &
@@ -628,8 +629,9 @@ state_sort_func (GtkTreeModel *model,
    * the presences.
    */
   ret_val = -tp_connection_presence_type_cmp_availability (
-      folks_has_presence_get_presence_type (FOLKS_HAS_PRESENCE (persona_a)),
-      folks_has_presence_get_presence_type (FOLKS_HAS_PRESENCE (persona_b)));
+      folks_presence_owner_get_presence_type (FOLKS_PRESENCE_OWNER (persona_a)),
+      folks_presence_owner_get_presence_type (
+          FOLKS_PRESENCE_OWNER (persona_b)));
 
   if (ret_val == 0) {
     /* Fallback: compare by name et al. */
diff --git a/libempathy-gtk/empathy-ui-utils.c b/libempathy-gtk/empathy-ui-utils.c
index 79328fd..b53be03 100644
--- a/libempathy-gtk/empathy-ui-utils.c
+++ b/libempathy-gtk/empathy-ui-utils.c
@@ -231,8 +231,8 @@ empathy_icon_name_for_individual (FolksIndividual *individual)
 	TpConnectionPresenceType presence;
 
 	folks_presence =
-	    folks_has_presence_get_presence_type (
-	        FOLKS_HAS_PRESENCE (individual));
+	    folks_presence_owner_get_presence_type (
+	        FOLKS_PRESENCE_OWNER (individual));
 	presence = empathy_folks_presence_type_to_tp (folks_presence);
 
 	return empathy_icon_name_for_presence (presence);
diff --git a/libempathy/empathy-contact.c b/libempathy/empathy-contact.c
index 86bb9f5..76091e4 100644
--- a/libempathy/empathy-contact.c
+++ b/libempathy/empathy-contact.c
@@ -510,8 +510,8 @@ empathy_contact_set_presence_message (EmpathyContact *contact,
 
   if (priv->persona != NULL)
     {
-      folks_has_presence_set_presence_message (
-          FOLKS_HAS_PRESENCE (priv->persona), message);
+      folks_presence_owner_set_presence_message (
+          FOLKS_PRESENCE_OWNER (priv->persona), message);
     }
 }
 
@@ -992,8 +992,8 @@ empathy_contact_get_presence_message (EmpathyContact *contact)
 
   if (priv->persona != NULL)
     {
-      return folks_has_presence_get_presence_message (
-          FOLKS_HAS_PRESENCE (priv->persona));
+      return folks_presence_owner_get_presence_message (
+          FOLKS_PRESENCE_OWNER (priv->persona));
     }
 
   return NULL;
@@ -1794,16 +1794,16 @@ static int
 presence_cmp_func (EmpathyContact *a,
     EmpathyContact *b)
 {
-  FolksHasPresence *presence_a, *presence_b;
+  FolksPresenceOwner *presence_a, *presence_b;
 
-  presence_a = FOLKS_HAS_PRESENCE (empathy_contact_get_persona (a));
-  presence_b = FOLKS_HAS_PRESENCE (empathy_contact_get_persona (b));
+  presence_a = FOLKS_PRESENCE_OWNER (empathy_contact_get_persona (a));
+  presence_b = FOLKS_PRESENCE_OWNER (empathy_contact_get_persona (b));
 
   /* We negate the result because we're sorting in reverse order (i.e. such that
    * the Personas with the highest presence are at the beginning of the list. */
-  return -folks_has_presence_typecmp (
-      folks_has_presence_get_presence_type (presence_a),
-      folks_has_presence_get_presence_type (presence_b));
+  return -folks_presence_owner_typecmp (
+      folks_presence_owner_get_presence_type (presence_a),
+      folks_presence_owner_get_presence_type (presence_b));
 }
 
 static gint



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/libempathy-gtk/empathy-individual-store.c b/libempathy-gtk/empathy-individual-store.c
index 0add70c..feec91a 100644
--- a/libempathy-gtk/empathy-individual-store.c
+++ b/libempathy-gtk/empathy-individual-store.c
@@ -164,21 +164,21 @@ individual_get_client_types (FolksIndividual *individual)
   personas = folks_individual_get_personas (individual);
   for (l = personas; l != NULL; l = l->next)
     {
-      FolksHasPresence *presence;
+      FolksPresenceOwner *presence;
 
-      /* We only want personas which implement FolksHasPresence */
-      if (!FOLKS_IS_HAS_PRESENCE (l->data))
+      /* We only want personas which implement FolksPresenceOwner */
+      if (!FOLKS_IS_PRESENCE_OWNER (l->data))
         continue;
 
-      presence = FOLKS_HAS_PRESENCE (l->data);
+      presence = FOLKS_PRESENCE_OWNER (l->data);
 
-      if (folks_has_presence_typecmp (
-              folks_has_presence_get_presence_type (presence),
+      if (folks_presence_owner_typecmp (
+              folks_presence_owner_get_presence_type (presence),
               presence_type) > 0)
         {
           TpContact *tp_contact;
 
-          presence_type = folks_has_presence_get_presence_type (presence);
+          presence_type = folks_presence_owner_get_presence_type (presence);
 
           tp_contact = tpf_persona_get_contact (TPF_PERSONA (l->data));
           types = tp_contact_get_client_types (tp_contact);
@@ -706,7 +706,8 @@ individual_store_contact_update (EmpathyIndividualStore *self,
     }
 
   /* Get online state now. */
-  now_online = folks_has_presence_is_online (FOLKS_HAS_PRESENCE (individual));
+  now_online = folks_presence_owner_is_online (
+      FOLKS_PRESENCE_OWNER (individual));
 
   if (!in_list)
     {
@@ -796,11 +797,11 @@ individual_store_contact_update (EmpathyIndividualStore *self,
           EMPATHY_INDIVIDUAL_STORE_COL_NAME,
             folks_aliasable_get_alias (FOLKS_ALIASABLE (individual)),
           EMPATHY_INDIVIDUAL_STORE_COL_PRESENCE_TYPE,
-            folks_has_presence_get_presence_type (
-                FOLKS_HAS_PRESENCE (individual)),
+            folks_presence_owner_get_presence_type (
+                FOLKS_PRESENCE_OWNER (individual)),
           EMPATHY_INDIVIDUAL_STORE_COL_STATUS,
-            folks_has_presence_get_presence_message (
-                FOLKS_HAS_PRESENCE (individual)),
+            folks_presence_owner_get_presence_message (
+                FOLKS_PRESENCE_OWNER (individual)),
           EMPATHY_INDIVIDUAL_STORE_COL_COMPACT, priv->is_compact,
           EMPATHY_INDIVIDUAL_STORE_COL_IS_GROUP, FALSE,
           EMPATHY_INDIVIDUAL_STORE_COL_IS_ONLINE, now_online,
@@ -1467,9 +1468,11 @@ individual_store_state_sort_func (GtkTreeModel *model,
    * the presences.
    */
   folks_presence_type_a =
-      folks_has_presence_get_presence_type (FOLKS_HAS_PRESENCE (individual_a));
+      folks_presence_owner_get_presence_type (
+          FOLKS_PRESENCE_OWNER (individual_a));
   folks_presence_type_b =
-      folks_has_presence_get_presence_type (FOLKS_HAS_PRESENCE (individual_b));
+      folks_presence_owner_get_presence_type (
+          FOLKS_PRESENCE_OWNER (individual_b));
   tp_presence_a = empathy_folks_presence_type_to_tp (folks_presence_type_a);
   tp_presence_b = empathy_folks_presence_type_to_tp (folks_presence_type_b);
 